configlet create


Quand tu ajoutes une nouvelle approche, un nouvel article ou un nouvel exercice, tu dois créer des fichiers aux noms très particuliers. Ces fichiers nécessitent aussi d'ajouter ou de mettre à jour des fichiers de configuration. Avec la commande create, configlet peut s'occuper de tout ça pour toi.

Utilisation

La commande create permet de créer les fichiers nécessaires pour ajouter une nouvelle approche, un nouvel article ou un nouvel exercice, mais aussi de modifier les fichiers de configuration.

configlet [global-options] create [command-options]

Options for create:
      --approach <slug>           The slug of the approach
      --article <slug>            The slug of the article
      --practice-exercise <slug>  The slug of the practice exercise
      --concept-exercise <slug>   The slug of the concept exercise
  -e, --exercise <slug>           Only operate on this exercise
  -o, --offline                   Do not update the cached 'problem-specifications' data

Crée un exercice d'entraînement

La documentation Ajouter un exercice d'entraînement explique en détail comment ajouter un exercice d'entraînement.

Crée un exercice d'apprentissage

Pour créer un exercice d'apprentissage, il faut en préciser le slug :

configlet create --concept-exercise bird-watcher

Cette commande crée les fichiers requis pour l'exercice d'apprentissage, comme décrit dans la documentation sur les exercices d'apprentissage.

Bien sûr, ce n'est que la première étape vers la création d'un exercice. Il te faudra ensuite :

  • Ajouter des tests au fichier de tests
  • Ajouter une implémentation d'exemple
  • Définir le contenu du fichier stub
  • Écrire l'introduction dans .docs/introduction.md
  • Écrire les instructions dans .docs/instructions.md
  • Dans le fichier .meta/config.json de l'exercice :
    • Ajouter le nom d'utilisateur GitHub des auteurs de l'exercice à la clé authors
  • Dans le fichier config.json du parcours :
    • Vérifier/mettre à jour la difficulté de l'exercice
    • Ajouter des concepts à la clé concepts
    • Ajouter des concepts à la clé prerequisites

Crée une approche

Pour créer les fichiers d'une approche, il faut préciser le slug de l'approche et celui de son exercice :

configlet create --approach recursion --exercise collatz-conjecture

Cette commande crée les fichiers requis pour l'approche, comme décrit dans la documentation sur les approches.

Crée un article

Pour créer les fichiers d'un article, il faut préciser le slug de l'article et celui de son exercice :

configlet create --article performance --exercise collatz-conjecture

Cette commande crée les fichiers requis pour l'article, comme décrit dans la documentation sur les articles.